##  Searching and Filtering for Jira Work Items
When linking or importing Jira work items, you can search for items in a project based on different criteria.
Search Criteria | Description
---|---
Summary or issue ID | Find Jira work items based on the summary or the unique issue ID.
Label | Filter by the labels that you’ve created in Jira.
Work type | Filter by work type. Common types include epic, story, task, and bug. Custom types may be available depending on the project configuration.


